@@ -1,4 +1,4 @@
-/* $Id: panel-app.c 28386 2008-10-23 17:35:49Z nick $
+/* $Id$
  *
  * Copyright (c) 2005 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -73,6 +73,7 @@
 #define SELECTION_NAME "XFCE4_PANEL"
 #define PANEL_LAUNCHER "launcher"
 #define SAVE_TIMEOUT   30000
+#define TEST_MULTIPLE_MONITORS FALSE
 
 #if defined(TIMER) && defined(G_HAVE_ISO_VARARGS)
 void
@@ -297,15 +298,15 @@ signal_pipe_io (GIOChannel   *source,
                 GIOCondition  cond,
                 gpointer      data)
 {
-    gint  signal;
+    gint  signal_;
     gsize bytes_read;
 
-    if (G_IO_STATUS_NORMAL == g_io_channel_read_chars (source, (gchar *)&signal, 
-                                                       sizeof (signal),
+    if (G_IO_STATUS_NORMAL == g_io_channel_read_chars (source, (gchar *)&signal_, 
+                                                       sizeof (signal_),
                                                        &bytes_read, NULL)
-        && sizeof(signal) == bytes_read)
+        && sizeof(signal_) == bytes_read)
     {
-        switch (signal)
+        switch (signal_)
         {
             case SIGUSR1:
                 DBG ("USR1 signal caught");
@@ -717,7 +718,7 @@ panel_app_run (gchar *client_id)
                                  SESSION_RESTART_IMMEDIATELY, 
                                  40, 
                                  client_id,
-                                 PACKAGE_NAME,
+                                 (gchar *) PACKAGE_NAME,
                                  NULL,
                                  restart_command, 
                                  g_strdupv (restart_command),
@@ -962,11 +963,12 @@ panel_app_about (GtkWidget *panel)
     GdkPixbuf     *pb;
 
     info = xfce_about_info_new (_("Xfce Panel"), "", _("Xfce Panel"),
-                                XFCE_COPYRIGHT_TEXT ("2006", "Jasper Huijsmans"),
+                                XFCE_COPYRIGHT_TEXT ("2009", "Jasper Huijsmans"),
                                 XFCE_LICENSE_GPL);
 
     xfce_about_info_set_homepage (info, "http://www.xfce.org");
 
+    /* TRANSLATORS: Used in the credits tab in the panel's about dialog */
     xfce_about_info_add_credit (info, "Jasper Huijsmans", "jasper@xfce.org", _("Developer"));
     xfce_about_info_add_credit (info, "Nick Schermer", "nick@xfce.org", _("Developer"));
 
