@@ -1,4 +1,4 @@
-/*  $Id: launcher-exec.c 29085 2009-01-02 20:38:36Z nick $
+/*  $Id$
  *
  *  Copyright (c) 2006-2007 Nick Schermer <nick@xfce.org>
  *
@@ -21,7 +21,10 @@
 #include <config.h>
 #endif
 
+#ifndef _GNU_SOURCE
 #define _GNU_SOURCE
+#endif
+
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -61,7 +64,6 @@
 #endif
 
 
-
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
 typedef struct
 {
@@ -421,10 +423,14 @@ launcher_exec_on_screen (GdkScreen     *screen,
     GtkWidget            *dialog;
     GSpawnFlags           flags = G_SPAWN_SEARCH_PATH;
     GPid                  pid;
+    gchar               **listenv;
 
     /* parse the full command */
     if ((argv = launcher_exec_parse_argv (entry, list, &error)) == NULL)
         goto error;
+        
+    /* get the environ variable */
+    listenv = g_listenv ();
 
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
     /* setup startup notification, only when not running in terminal */
@@ -457,16 +463,16 @@ launcher_exec_on_screen (GdkScreen     *screen,
                 sn_launcher_context_initiate (sn_launcher, g_get_prgname (), argv[0], CurrentTime);
 
                 /* count environ items */
-                for (n = 0; environ[n] != NULL; ++n)
+                for (n = 0; listenv[n] != NULL; ++n)
                     ;
 
                 /* alloc new envp string */
                 envp = g_new (gchar *, n + 3);
 
                 /* copy the environ vars into the envp */
-                for (n = m = 0; environ[n] != NULL; ++n)
-                    if (G_LIKELY (strncmp (environ[n], "DESKTOP_STARTUP_ID", 18) != 0 && strncmp (environ[n], "DISPLAY", 7) != 0))
-                        envp[m++] = g_strdup (environ[n]);
+                for (n = m = 0; listenv[n] != NULL; ++n)
+                    if (G_LIKELY (strncmp (listenv[n], "DESKTOP_STARTUP_ID", 18) != 0 && strncmp (listenv[n], "DISPLAY", 7) != 0))
+                        envp[m++] = g_strdup_printf ("%s=%s", listenv[n], g_getenv (listenv[n]));
 
                 /* append the startup notification id */
                 envp[m++] = g_strconcat ("DESKTOP_STARTUP_ID=", sn_launcher_context_get_startup_id (sn_launcher), NULL);
@@ -485,16 +491,16 @@ launcher_exec_on_screen (GdkScreen     *screen,
     }
 #else
     /* count environ items */
-    for (n = 0; environ[n] != NULL; ++n)
+    for (n = 0; listenv[n] != NULL; ++n)
         ;
 
     /* alloc new envp string */
     envp = g_new (gchar *, n + 2);
 
     /* copy the environ vars into the envp */
-    for (n = m = 0; environ[n] != NULL; ++n)
-        if (G_LIKELY (strncmp (environ[n], "DISPLAY", 7) != 0))
-            envp[m++] = g_strdup (environ[n]);
+    for (n = m = 0; listenv[n] != NULL; ++n)
+        if (G_LIKELY (strncmp (listenv[n], "DISPLAY", 7) != 0))
+            envp[m++] = g_strdup_printf ("%s=%s", listenv[n], g_getenv (listenv[n]));
 
     /* workaround for the failure of gdk_spawn_on_screen to setup the correct DISPLAY env */
     dpyname = gdk_screen_make_display_name (screen);
@@ -554,6 +560,9 @@ launcher_exec_on_screen (GdkScreen     *screen,
         g_strfreev (envp);
 #endif
 
+    /* cleanup */
+    g_strfreev (listenv);
+
 error:
     if (G_UNLIKELY (error != NULL))
     {
