@@ -1,4 +1,4 @@
-/*  $Id: launcher.h 28381 2008-10-23 16:10:46Z nick $
+/*  $Id$
  *
  *  Copyright (c) 2005-2007 Jasper Huijsmans <jasper@xfce.org>
  *  Copyright (c) 2006-2007 Nick Schermer <nick@xfce.org>
@@ -25,12 +25,12 @@
 #include <exo/exo.h>
 #include <libxfce4panel/xfce-panel-plugin.h>
 
-#define BORDER                     (8)
+#define BORDER                     (6)
 #define LAUNCHER_NEW_TOOLTIP_API   (GTK_CHECK_VERSION (2,11,6))
 #define LAUNCHER_ARROW_SIZE        (16)
 #define LAUNCHER_POPUP_DELAY       (225)
 #define LAUNCHER_TOOLTIP_SIZE      (32)
-#define LAUNCHER_MENU_SIZE	       (24)
+#define LAUNCHER_MENU_SIZE         (24)
 #define LAUNCHER_STARTUP_TIMEOUT   (30 * 1000)
 #define LAUNCHER_TREE_ICON_SIZE    (24)
 #define LAUNCHER_CHOOSER_ICON_SIZE (48)
@@ -58,6 +58,10 @@ struct _LauncherEntry
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
     guint     startup : 1;
 #endif
+
+#if LAUNCHER_NEW_TOOLTIP_API
+    GdkPixbuf *tooltip_cache;
+#endif
 };
 
 struct _LauncherPlugin
@@ -103,10 +107,10 @@ enum
 /* target types for dropping in the launcher plugin */
 static const GtkTargetEntry drop_targets[] =
 {
-    { "text/uri-list", 0, 0, },
-    { "STRING",	       0, 0 },
-    { "UTF8_STRING",   0, 0 },
-    { "text/plain",    0, 0 },
+    { (gchar *) "text/uri-list", 0, 0, },
+    { (gchar *) "STRING",	       0, 0 },
+    { (gchar *) "UTF8_STRING",   0, 0 },
+    { (gchar *) "text/plain",    0, 0 },
 };
 
 
